import {
  select,
  json,
  csv,
  geoPath,
  geoAlbersUsa,
  geoMercator,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';
import { feature, mesh } from 'topojson';

const svg = select('svg');

const projection = geoMercator()
  .translate([-1800, 1100])
  .scale([1600]);
const pathGenerator = geoPath().projection(projection);

const colorScale = scaleOrdinal(schemeCategory10);

json(
  'https://cdn.jsdelivr.net/npm/world-atlas@2/countries-10m.json' 
).then((data) => {
  console.log(data)
  const countryShapes = feature(
    data,
    data.objects['india-districts-2019-734']
  );
countryShapes.features.forEach((d) => console.log(d.properties)  );
 
  svg
    .selectAll('path')
    .data(countryShapes.features)
    .enter()
    .append('path')
    .attr('class', 'states')
    .attr('fill', (d) => colorScale(d.properties.NAME_1))
    .attr('d', (d) => pathGenerator(d))
    .append('title')
    .text((d) => d.properties.NAME_1);

svg
  .selectAll('text')
  .data(countryShapes.features)
  .enter()
  .append('text')
  .text((d) => d.properties.NAME_1)
  .attr('x', d=>  pathGenerator.centroid(d)[0]   )
  .attr('y',d=>pathGenerator.centroid(d)[1])
    .attr("text-anchor", "middle")
   .attr("font-size", "16px");
});